/*****************************************************************************
*                              18fSensors.h                                  *
******************************************************************************

Implements communication between the Controller board and the Sensor boards
via I2C protocol.

Date:		Author:				Comment:
------------------------------------------------------------------------------
2006-2-6	Jonathan Karpick	Assembly version
2006-5-8	Jonathan Karpick	Port to C
2006-7-5	Barrett Heyneman	General Code cleanup, using MPLAB's C18 I2C
								functions, moved sensor specific functionality
								to this file.

*****************************************************************************/

#ifndef __18FSENSORS_H
#define __18FSENSORS_H

#include "18fUtil.h"


/*****************************************************************************
*					PUBLIC TYPES, MACROS, DEFINITIONS                        *
*****************************************************************************/

#define NUM_SENSORS		4		//Number of sensors

/* Target baud rate in KBps */
#define I2C_BAUD		100

/* Value used to set that baud rate (as close as possible) */
#define I2C_NUMBR	((unsigned char)((unsigned long)FOSC/(4*I2C_BAUD) - 1))


/*****************************************************************************
							PUBLIC VARIABLES
*****************************************************************************/
/* Holds the latest readings from the sensors */
extern unsigned char SensorReading[NUM_SENSORS];


/*****************************************************************************
						PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Initializes the I2C in master mode and initializes the sensor readings. */
void InitSensors(void);

/* Polls all the sensors and stores the values in the sensor reading array.*/
void PollSensors(void);

#endif //__18FSENSOR_H
