/*****************************************************************************
 *                                 Display.h                                 *
 *****************************************************************************

Display routines for the StickyBot controller board.

Date:		Author:				Comment:
------------------------------------------------------------------------------
2006-6-30	Barrett Heyneman	Original version, abstracting out all display
									control (LEDs) and adding error display
									functionality.

*****************************************************************************/

#ifndef DISPLAY_H
#define DISPLAY_H

#include <p18cxxx.h>


/*****************************************************************************
						PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/
#define	G_LED				(PORTCbits.RC0)
#define	R_LED				(PORTCbits.RC1)

#define SetGreen(status)	(G_LED = status)
#define SetRed(status)		(R_LED = status)


/* The number of LED flashes for a given type of error.  Note, either all need
 * to be specified, or the fact that enum automatically increments the value
 * assigned must be taken into account */
typedef enum {
	NO_GAIT = 1,
	UNHANDLED_KEY
} Error_t;


/*****************************************************************************
						PUBLIC FUNCTION PROTOYPES
*****************************************************************************/

/* Initializes the display (ports, pins, etc) */
void InitDisplay(void);

/* Indicates to the user that everything has initialized correctly */
void Hello(void);

/* Flashes the red LED a number of times corresponding to the error code (as
 * defined in the error typedef above).  This code blocks until the start key
 * is pressed.
 */
void Error(Error_t err);

#endif /* DISPLAY_H */
