/*****************************************************************************
 *                                   Keys.h                                  *
 *****************************************************************************
 
Key press routines for StickyBot Controller board (specifically for PIC18Fxxx)
Assumes that the keys are normally high (pulled-up in hardware).

Date:		Author:				Comment:
------------------------------------------------------------------------------
2003-10-28	Virgilio Mattoli	Original (v1.3 assembly code)
2006-5-8	Jonathan Karpick	Port to C
2006-7-3	Barrett Heyneman	General code cleanup

*****************************************************************************/

#ifndef __KEYS_H
#define __KEYS_H

#include "18fUtil.h"


/*****************************************************************************
						PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/

/* Hardware Settings */

/* Value must correspond to bit number on key port. */
typedef enum {
	KEY_0 = 0,
	KEY_1 = 1
} Key_t;



/*****************************************************************************
						PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Initializes all Key pins */
void InitKeys(void);

/* Returns a Byte_t with bits clear for all keys that are pressed */
Byte_t CheckKeys(void);

/* Returns 1 if the key is pressed, 0 if it isn't */
unsigned char CheckSingleKey(Key_t key);


#endif
